==> omegaml-0.14.0.tar.gz: omegaml-0.14.0/omegaml/runtimes/envinstall/envinstall/__init__.py <==
import os
import subprocess


def run(om, *args, package=None, file=None, action='install', options=None, **kwargs):
    """ install packages in user environment

    Installation:
        om scripts put envinstall envinstall

    Usage:
        # install
        om datasets put requirements.txt .system/requirements.txt
        om runtime script envinstall

        # uninstall
        om runtime script envinstall run action=uninstall
    """
    lockfile = '/app/pylib/user/envinstall.lock'
    reqfile = '.system/requirements.txt'
    package = package or ' '
    try:
        with open(lockfile, 'x') as flock:
            # only run if we can get an exclusive lock
            reqfn = '/tmp/envreq.txt'
            if not package:
                with open(reqfn, 'wb') as fout:
                    reqs = om.scripts.get(reqfile).read()
                    fout.write(reqs)
                reqspec = f'-r {reqfn}'
            else:
                reqspec = package
            action_opts = {
                'install': f'-U --user {reqspec}',
                'uninstall': f'-y {reqspec}'
            }
            opts = options or action_opts.get(action) or ''
            pipcmd = f'pip {action} {opts}'
            process = subprocess.run(pipcmd.split(' '),
                                     stdout=subprocess.PIPE,
                                     stderr=subprocess.STDOUT,
                                     encoding='utf-8')
    except IOError as e :
        result = f'another envinstall process is running on this node: {e}'
    else:
        result = str(process.stdout)
    finally:
        try:
            os.remove(lockfile)
        except:
            pass
    return result

==> omegaml-0.16.4.tar.gz: omegaml-0.16.4/omegaml/runtimes/envinstall/envinstall/__init__.py <==
import os
import subprocess


def run(om, *args, package=None, requirements=None, action='install', options=None, **kwargs):
    """ install packages in user environment

    Installation:
        # from the command line
        om runtime env install
        # from the omegaml/runtimes/envinstall directory
        om scripts put envinstall envinstall

    Usage:
        # install
        om datasets put requirements.txt .system/requirements.txt
        om runtime script envinstall

        # uninstall
        om runtime script envinstall run action=uninstall
    """
    lockfile = '/tmp/envinstall.lock'
    reqfile = requirements or '.system/requirements.txt'
    package = package or ' '
    try:
        with open(lockfile, 'x') as flock:
            # only run if we can get an exclusive lock
            reqfn = '/tmp/envreq.txt'
            if reqfile:
                with open(reqfn, 'wb') as fout:
                    reqs = om.scripts.get(reqfile).read()
                    fout.write(reqs)
                reqspec = f'-r {reqfn}'
            else:
                reqspec = package
            action_opts = {
                'install': f'-U --user {reqspec}',
                'uninstall': f'-y {reqspec}'
            }
            opts = options or action_opts.get(action) or ''
            pipcmd = f'pip {action} {opts}'
            process = subprocess.run(pipcmd.split(' '),
                                     stdout=subprocess.PIPE,
                                     stderr=subprocess.STDOUT,
                                     encoding='utf-8')
    except IOError as e :
        result = f'another envinstall process is running on this node: {e}'
    else:
        result = str(process.stdout)
    finally:
        try:
            os.remove(lockfile)
        except:
            pass
    return result
